==> global_agent_toolkit-0.0.5-py3-none-any.whl: gat/generations/models/chain_of_thought.py <==
from typing import Sequence

from pydantic import BaseModel, Field

from gat.generations.models.step import Step


class ChainOfThought[T](BaseModel):
    """Structured reasoning process with final answer.

    Attributes:
        general_title: High-level description of reasoning goal
        steps: Logical steps in reasoning process
        final_answer: Conclusion of the reasoning chain

    Example:
        >>> ChainOfThought(
        ...     general_title="Math problem solution",
        ...     steps=[step1, step2],
        ...     final_answer=42
        ... )
    """

    general_title: str = Field(
        description="A brief label or description that identifies the purpose of the reasoning.",
        examples=["Sum of two numbers", "Logical problem solving"],
    )

    steps: Sequence[Step] = Field(
        description="The sequence of steps that make up the full reasoning process.",
        examples=[
            [
                {
                    "step_number": 1,
                    "explanation": "Analyze input data",
                    "details": [
                        {"detail": "Data: 234 and 567"},
                        {"detail": "Check if they are integers"},
                    ],
                },
                {
                    "step_number": 2,
                    "explanation": "Perform the calculation",
                    "details": [
                        {"detail": "234 + 567 = 801"},
                    ],
                },
            ]
        ],
    )

    final_answer: T = Field(
        description="The conclusion or result after all the reasoning steps."
    )

    def as_string(self, lang: str = "en") -> str:
        """Return a localized string representation of the ChainOfThought.

        Args:
            lang: ISO language code for the output format (default: "en" for English)

        Returns:
            str: A formatted string showing the reasoning process and final answer in the specified language

        Example:
            >>> print(chain_of_thought.as_string())  # Default English
            MATH PROBLEM SOLUTION

            Step 1: Analyze input data
            - Data: 234 and 567
            - Check if they are integers

            Step 2: Perform the calculation
            - 234 + 567 = 801

            Final Answer: 801

            >>> print(chain_of_thought.as_string("es"))  # Spanish
            SOLUCIÓN DEL PROBLEMA MATEMÁTICO

            Paso 1: Analizar datos de entrada
            - Datos: 234 y 567
            - Comprobar si son números enteros

            Paso 2: Realizar el cálculo
            - 234 + 567 = 801

            Respuesta Final: 801

            >>> print(chain_of_thought.as_string("pt"))  # Portuguese
            SOLUÇÃO DO PROBLEMA MATEMÁTICO

            Passo 1: Analisar dados de entrada
            - Dados: 234 e 567
            - Verificar se são números inteiros

            Passo 2: Realizar o cálculo
            - 234 + 567 = 801

            Resposta Final: 801
        """
        # Define language-specific terms
        translations = {
            "en": {"step": "Step", "final_answer": "Final Answer"},
            "es": {"step": "Paso", "final_answer": "Respuesta Final"},
            "fr": {"step": "Étape", "final_answer": "Réponse Finale"},
            "de": {"step": "Schritt", "final_answer": "Endgültige Antwort"},
            "pt": {"step": "Passo", "final_answer": "Resposta Final"},
        }

        # Default to English if requested language is not available
        if lang not in translations:
            lang = "en"

        # Get translation dictionary for the specified language
        t = translations[lang]

        # Start with the title
        result = f"{self.general_title.upper()}\n\n"

        # Add each step with its details
        for step in self.steps:
            result += f"{t['step']} {step.step_number}: {step.explanation}\n"
            for detail in step.details:
                result += f"- {detail.detail}\n"
            result += "\n"

        # Add the final answer
        result += f"{t['final_answer']}: {self.final_answer}"

        return result

==> global_agent_toolkit-0.0.15-py3-none-any.whl: gat/generations/models/chain_of_thought.py <==
from typing import Sequence

from pydantic import BaseModel, Field

from gat.generations.models.step import Step


class ChainOfThought[T](BaseModel):
    """Structured reasoning process with final answer.

    Attributes:
        general_title: High-level description of reasoning goal
        steps: Logical steps in reasoning process
        final_answer: Conclusion of the reasoning chain

    Example:
        >>> ChainOfThought(
        ...     general_title="Math problem solution",
        ...     steps=[step1, step2],
        ...     final_answer=42
        ... )
    """

    general_title: str = Field(
        description="A brief label or description that identifies the purpose of the reasoning.",
        # examples=["Sum of two numbers", "Logical problem solving"],
    )

    steps: Sequence[Step] = Field(
        description="The sequence of steps that make up the full reasoning process.",
        # examples=[
        #     [
        #         {
        #             "step_number": 1,
        #             "explanation": "Analyze input data",
        #             "details": [
        #                 {"detail": "Data: 234 and 567"},
        #                 {"detail": "Check if they are integers"},
        #             ],
        #         },
        #         {
        #             "step_number": 2,
        #             "explanation": "Perform the calculation",
        #             "details": [
        #                 {"detail": "234 + 567 = 801"},
        #             ],
        #         },
        #     ]
        # ],
    )

    final_answer: T = Field(
        description="The conclusion or result after all the reasoning steps."
    )

    def as_string(self, lang: str = "en") -> str:
        """Return a localized string representation of the ChainOfThought.

        Args:
            lang: ISO language code for the output format (default: "en" for English)

        Returns:
            str: A formatted string showing the reasoning process and final answer in the specified language

        Example:
            >>> print(chain_of_thought.as_string())  # Default English
            MATH PROBLEM SOLUTION

            Step 1: Analyze input data
            - Data: 234 and 567
            - Check if they are integers

            Step 2: Perform the calculation
            - 234 + 567 = 801

            Final Answer: 801

            >>> print(chain_of_thought.as_string("es"))  # Spanish
            SOLUCIÓN DEL PROBLEMA MATEMÁTICO

            Paso 1: Analizar datos de entrada
            - Datos: 234 y 567
            - Comprobar si son números enteros

            Paso 2: Realizar el cálculo
            - 234 + 567 = 801

            Respuesta Final: 801

            >>> print(chain_of_thought.as_string("pt"))  # Portuguese
            SOLUÇÃO DO PROBLEMA MATEMÁTICO

            Passo 1: Analisar dados de entrada
            - Dados: 234 e 567
            - Verificar se são números inteiros

            Passo 2: Realizar o cálculo
            - 234 + 567 = 801

            Resposta Final: 801
        """
        # Define language-specific terms
        translations = {
            "en": {"step": "Step", "final_answer": "Final Answer"},
            "es": {"step": "Paso", "final_answer": "Respuesta Final"},
            "fr": {"step": "Étape", "final_answer": "Réponse Finale"},
            "de": {"step": "Schritt", "final_answer": "Endgültige Antwort"},
            "pt": {"step": "Passo", "final_answer": "Resposta Final"},
        }

        # Default to English if requested language is not available
        if lang not in translations:
            lang = "en"

        # Get translation dictionary for the specified language
        t = translations[lang]

        # Start with the title
        result = f"{self.general_title.upper()}\n\n"

        # Add each step with its details
        for step in self.steps:
            result += f"{t['step']} {step.step_number}: {step.explanation}\n"
            for detail in step.details:
                result += f"- {detail.detail}\n"
            result += "\n"

        # Add the final answer
        result += f"{t['final_answer']}: {self.final_answer}"

        return result
